'use strict';

var webhooksMethods = require('@octokit/webhooks-methods');
var pluginEventsNode = require('@backstage/plugin-events-node');

function createGithubSignatureValidator(config) {
  const secret = config.getString("events.modules.github.webhookSecret");
  return async (request, context) => {
    const signature = request.headers["x-hub-signature-256"];
    if (!signature || !await webhooksMethods.verify(secret, JSON.stringify(request.body), signature)) {
      context.reject({
        status: 403,
        payload: { message: "invalid signature" }
      });
    }
  };
}

class GithubEventRouter extends pluginEventsNode.SubTopicEventRouter {
  constructor(options) {
    super({
      events: options.events,
      topic: "github"
    });
  }
  getSubscriberId() {
    return "GithubEventRouter";
  }
  determineSubTopic(params) {
    var _a;
    return (_a = params.metadata) == null ? void 0 : _a["x-github-event"];
  }
}

exports.GithubEventRouter = GithubEventRouter;
exports.createGithubSignatureValidator = createGithubSignatureValidator;
//# sourceMappingURL=GithubEventRouter-DMHCGPBX.cjs.js.map
